==> enterprisemodules-wls_config-3.0.21.tar.gz: enterprisemodules-wls_config-3.0.21/meta/wls_datasource.py <==
username      = sys.argv[1]
password      = sys.argv[2]
url           = sys.argv[3]

connect(username, password, url)

execfile('/vagrant/files/wlst/common.py.erb')
execfile('/vagrant/meta/get_properties.py')

print 'base properties'
properties('/JDBCSystemResources/test_ds','wls_datasource')  # All default properties

print 'JDBCConnectionPoolParams'
properties('/JDBCSystemResources/test_ds/JDBCResource/test_ds/JDBCConnectionPoolParams/test_ds','wls_datasource', 'pool_', 'JDBCResource/%{datasource_name}/JDBCConnectionPoolParams/%{datasource_name}/')  # All default properties

print 'JDBCDriverParams'
properties('/JDBCSystemResources/test_ds/JDBCResource/test_ds/JDBCDriverParams/test_ds','wls_datasource', 'driver_', 'JDBCResource/%{datasource_name}/JDBCDriverParams/%{datasource_name}/')  # All default properties

print 'JDBCOracleParams'
properties('/JDBCSystemResources/test_ds/JDBCResource/test_ds/JDBCOracleParams/test_ds','wls_datasource', 'oracle_', 'JDBCResource/%{datasource_name}/JDBCOracleParams/%{datasource_name}/')  # All default properties

print 'JDBCDataSourceParams'
properties('/JDBCSystemResources/test_ds/JDBCResource/test_ds/JDBCDataSourceParams/test_ds','wls_datasource', 'ds_', 'JDBCResource/%{datasource_name}/JDBCDataSourceParams/%{datasource_name}/')  # All default properties

print 'JDBCXAParams'
properties('/JDBCSystemResources/test_ds/JDBCResource/test_ds/JDBCXAParams/test_ds','wls_datasource', 'xa_', 'JDBCResource/%{datasource_name}/JDBCXAParams/%{datasource_name}/')  # All default properties

==> enterprisemodules-wls_config-3.3.8.tar.gz: enterprisemodules-wls_config-3.3.8/meta/wls_datasource.py <==
username      = sys.argv[1]
password      = sys.argv[2]
url           = sys.argv[3]

connect(username, password, url)

execfile('/etc/puppetlabs/code/environments/production/modules/wls_config//lib/puppet/provider/wls_config/wlst/templates/common.py.erb')
execfile('/etc/puppetlabs/code/environments/production/modules/wls_config/meta/get_properties.py')

print 'base properties'
properties('/JDBCSystemResources/test_ds','wls_datasource')  # All default properties

print 'JDBCConnectionPoolParams'
properties('/JDBCSystemResources/test_ds/JDBCResource/test_ds/JDBCConnectionPoolParams/test_ds','wls_datasource', 'pool_', 'JDBCResource/%{datasource_name}/JDBCConnectionPoolParams/%{datasource_name}/')  # All default properties

print 'JDBCDriverParams'
properties('/JDBCSystemResources/test_ds/JDBCResource/test_ds/JDBCDriverParams/test_ds','wls_datasource', 'driver_', 'JDBCResource/%{datasource_name}/JDBCDriverParams/%{datasource_name}/')  # All default properties

print 'JDBCOracleParams'
properties('/JDBCSystemResources/test_ds/JDBCResource/test_ds/JDBCOracleParams/test_ds','wls_datasource', 'oracle_', 'JDBCResource/%{datasource_name}/JDBCOracleParams/%{datasource_name}/')  # All default properties

print 'JDBCDataSourceParams'
properties('/JDBCSystemResources/test_ds/JDBCResource/test_ds/JDBCDataSourceParams/test_ds','wls_datasource', 'ds_', 'JDBCResource/%{datasource_name}/JDBCDataSourceParams/%{datasource_name}/')  # All default properties

print 'JDBCXAParams'
properties('/JDBCSystemResources/test_ds/JDBCResource/test_ds/JDBCXAParams/test_ds','wls_datasource', 'xa_', 'JDBCResource/%{datasource_name}/JDBCXAParams/%{datasource_name}/')  # All default properties
